==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkStructuredData.java <==
// java wrapper for vtkStructuredData object
//

package vtk;
import vtk.*;

public class vtkStructuredData extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int SetDimensions_2(int id0[],int id1[]);
  public int SetDimensions(int id0[],int id1[])
    { return SetDimensions_2(id0,id1); }

  private native int SetExtent_3(int id0[],int id1[]);
  public int SetExtent(int id0[],int id1[])
    { return SetExtent_3(id0,id1); }

  private native int GetDataDescription_4(int id0[]);
  public int GetDataDescription(int id0[])
    { return GetDataDescription_4(id0); }

  private native int GetDataDescriptionFromExtent_5(int id0[]);
  public int GetDataDescriptionFromExtent(int id0[])
    { return GetDataDescriptionFromExtent_5(id0); }

  private native int GetDataDimension_6(int id0);
  public int GetDataDimension(int id0)
    { return GetDataDimension_6(id0); }

  private native int GetDataDimension_7(int id0[]);
  public int GetDataDimension(int id0[])
    { return GetDataDimension_7(id0); }

  private native int GetNumberOfPoints_8(int id0[],int id1);
  public int GetNumberOfPoints(int id0[],int id1)
    { return GetNumberOfPoints_8(id0,id1); }

  private native int GetNumberOfCells_9(int id0[],int id1);
  public int GetNumberOfCells(int id0[],int id1)
    { return GetNumberOfCells_9(id0,id1); }

  private native void GetCellExtentFromPointExtent_10(int id0[],int id1[],int id2);
  public void GetCellExtentFromPointExtent(int id0[],int id1[],int id2)
    { GetCellExtentFromPointExtent_10(id0,id1,id2); }

  private native void GetDimensionsFromExtent_11(int id0[],int id1[],int id2);
  public void GetDimensionsFromExtent(int id0[],int id1[],int id2)
    { GetDimensionsFromExtent_11(id0,id1,id2); }

  private native void GetCellDimensionsFromExtent_12(int id0[],int id1[],int id2);
  public void GetCellDimensionsFromExtent(int id0[],int id1[],int id2)
    { GetCellDimensionsFromExtent_12(id0,id1,id2); }

  private native void GetCellDimensionsFromPointDimensions_13(int id0[],int id1[]);
  public void GetCellDimensionsFromPointDimensions(int id0[],int id1[])
    { GetCellDimensionsFromPointDimensions_13(id0,id1); }

  private native void GetLocalStructuredCoordinates_14(int id0[],int id1[],int id2[],int id3);
  public void GetLocalStructuredCoordinates(int id0[],int id1[],int id2[],int id3)
    { GetLocalStructuredCoordinates_14(id0,id1,id2,id3); }

  private native void GetGlobalStructuredCoordinates_15(int id0[],int id1[],int id2[],int id3);
  public void GetGlobalStructuredCoordinates(int id0[],int id1[],int id2[],int id3)
    { GetGlobalStructuredCoordinates_15(id0,id1,id2,id3); }

  private native void GetCellPoints_16(int id0,vtkIdList id1,int id2,int id3[]);
  public void GetCellPoints(int id0,vtkIdList id1,int id2,int id3[])
    { GetCellPoints_16(id0,id1,id2,id3); }

  private native void GetPointCells_17(int id0,vtkIdList id1,int id2[]);
  public void GetPointCells(int id0,vtkIdList id1,int id2[])
    { GetPointCells_17(id0,id1,id2); }

  private native void GetCellNeighbors_18(int id0,vtkIdList id1,vtkIdList id2,int id3[]);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2,int id3[])
    { GetCellNeighbors_18(id0,id1,id2,id3); }

  private native int ComputePointIdForExtent_19(int id0[],int id1[],int id2);
  public int ComputePointIdForExtent(int id0[],int id1[],int id2)
    { return ComputePointIdForExtent_19(id0,id1,id2); }

  private native int ComputeCellIdForExtent_20(int id0[],int id1[],int id2);
  public int ComputeCellIdForExtent(int id0[],int id1[],int id2)
    { return ComputeCellIdForExtent_20(id0,id1,id2); }

  private native int ComputePointId_21(int id0[],int id1[],int id2);
  public int ComputePointId(int id0[],int id1[],int id2)
    { return ComputePointId_21(id0,id1,id2); }

  private native int ComputeCellId_22(int id0[],int id1[],int id2);
  public int ComputeCellId(int id0[],int id1[],int id2)
    { return ComputeCellId_22(id0,id1,id2); }

  private native void ComputeCellStructuredCoordsForExtent_23(int id0,int id1[],int id2[],int id3);
  public void ComputeCellStructuredCoordsForExtent(int id0,int id1[],int id2[],int id3)
    { ComputeCellStructuredCoordsForExtent_23(id0,id1,id2,id3); }

  private native void ComputeCellStructuredCoords_24(int id0,int id1[],int id2[],int id3);
  public void ComputeCellStructuredCoords(int id0,int id1[],int id2[],int id3)
    { ComputeCellStructuredCoords_24(id0,id1,id2,id3); }

  private native void ComputePointStructuredCoordsForExtent_25(int id0,int id1[],int id2[],int id3);
  public void ComputePointStructuredCoordsForExtent(int id0,int id1[],int id2[],int id3)
    { ComputePointStructuredCoordsForExtent_25(id0,id1,id2,id3); }

  private native void ComputePointStructuredCoords_26(int id0,int id1[],int id2[],int id3);
  public void ComputePointStructuredCoords(int id0,int id1[],int id2[],int id3)
    { ComputePointStructuredCoords_26(id0,id1,id2,id3); }

  public vtkStructuredData() { super(); }

  public vtkStructuredData(long id) { super(id); }

}

==> vtk-8.1.0-6-aarch64.pkg.tar.xz: vtk/vtkStructuredData.java <==
// java wrapper for vtkStructuredData object
//

package vtk;
import vtk.*;

public class vtkStructuredData extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int SetDimensions_2(int id0[],int id1[]);
  public int SetDimensions(int id0[],int id1[])
    { return SetDimensions_2(id0,id1); }

  private native int SetExtent_3(int id0[],int id1[]);
  public int SetExtent(int id0[],int id1[])
    { return SetExtent_3(id0,id1); }

  private native int GetDataDescription_4(int id0[]);
  public int GetDataDescription(int id0[])
    { return GetDataDescription_4(id0); }

  private native int GetDataDescriptionFromExtent_5(int id0[]);
  public int GetDataDescriptionFromExtent(int id0[])
    { return GetDataDescriptionFromExtent_5(id0); }

  private native int GetDataDimension_6(int id0);
  public int GetDataDimension(int id0)
    { return GetDataDimension_6(id0); }

  private native int GetDataDimension_7(int id0[]);
  public int GetDataDimension(int id0[])
    { return GetDataDimension_7(id0); }

  private native int GetNumberOfPoints_8(int id0[],int id1);
  public int GetNumberOfPoints(int id0[],int id1)
    { return GetNumberOfPoints_8(id0,id1); }

  private native int GetNumberOfCells_9(int id0[],int id1);
  public int GetNumberOfCells(int id0[],int id1)
    { return GetNumberOfCells_9(id0,id1); }

  private native void GetCellExtentFromPointExtent_10(int id0[],int id1[],int id2);
  public void GetCellExtentFromPointExtent(int id0[],int id1[],int id2)
    { GetCellExtentFromPointExtent_10(id0,id1,id2); }

  private native void GetDimensionsFromExtent_11(int id0[],int id1[],int id2);
  public void GetDimensionsFromExtent(int id0[],int id1[],int id2)
    { GetDimensionsFromExtent_11(id0,id1,id2); }

  private native void GetCellDimensionsFromExtent_12(int id0[],int id1[],int id2);
  public void GetCellDimensionsFromExtent(int id0[],int id1[],int id2)
    { GetCellDimensionsFromExtent_12(id0,id1,id2); }

  private native void GetCellDimensionsFromPointDimensions_13(int id0[],int id1[]);
  public void GetCellDimensionsFromPointDimensions(int id0[],int id1[])
    { GetCellDimensionsFromPointDimensions_13(id0,id1); }

  private native void GetLocalStructuredCoordinates_14(int id0[],int id1[],int id2[],int id3);
  public void GetLocalStructuredCoordinates(int id0[],int id1[],int id2[],int id3)
    { GetLocalStructuredCoordinates_14(id0,id1,id2,id3); }

  private native void GetGlobalStructuredCoordinates_15(int id0[],int id1[],int id2[],int id3);
  public void GetGlobalStructuredCoordinates(int id0[],int id1[],int id2[],int id3)
    { GetGlobalStructuredCoordinates_15(id0,id1,id2,id3); }

  private native void GetCellPoints_16(int id0,vtkIdList id1,int id2,int id3[]);
  public void GetCellPoints(int id0,vtkIdList id1,int id2,int id3[])
    { GetCellPoints_16(id0,id1,id2,id3); }

  private native void GetPointCells_17(int id0,vtkIdList id1,int id2[]);
  public void GetPointCells(int id0,vtkIdList id1,int id2[])
    { GetPointCells_17(id0,id1,id2); }

  private native void GetCellNeighbors_18(int id0,vtkIdList id1,vtkIdList id2,int id3[]);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2,int id3[])
    { GetCellNeighbors_18(id0,id1,id2,id3); }

  private native void GetCellNeighbors_19(int id0,vtkIdList id1,vtkIdList id2,int id3[],int id4[]);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2,int id3[],int id4[])
    { GetCellNeighbors_19(id0,id1,id2,id3,id4); }

  private native int ComputePointIdForExtent_20(int id0[],int id1[],int id2);
  public int ComputePointIdForExtent(int id0[],int id1[],int id2)
    { return ComputePointIdForExtent_20(id0,id1,id2); }

  private native int ComputeCellIdForExtent_21(int id0[],int id1[],int id2);
  public int ComputeCellIdForExtent(int id0[],int id1[],int id2)
    { return ComputeCellIdForExtent_21(id0,id1,id2); }

  private native int ComputePointId_22(int id0[],int id1[],int id2);
  public int ComputePointId(int id0[],int id1[],int id2)
    { return ComputePointId_22(id0,id1,id2); }

  private native int ComputeCellId_23(int id0[],int id1[],int id2);
  public int ComputeCellId(int id0[],int id1[],int id2)
    { return ComputeCellId_23(id0,id1,id2); }

  private native void ComputeCellStructuredCoordsForExtent_24(int id0,int id1[],int id2[],int id3);
  public void ComputeCellStructuredCoordsForExtent(int id0,int id1[],int id2[],int id3)
    { ComputeCellStructuredCoordsForExtent_24(id0,id1,id2,id3); }

  private native void ComputeCellStructuredCoords_25(int id0,int id1[],int id2[],int id3);
  public void ComputeCellStructuredCoords(int id0,int id1[],int id2[],int id3)
    { ComputeCellStructuredCoords_25(id0,id1,id2,id3); }

  private native void ComputePointStructuredCoordsForExtent_26(int id0,int id1[],int id2[],int id3);
  public void ComputePointStructuredCoordsForExtent(int id0,int id1[],int id2[],int id3)
    { ComputePointStructuredCoordsForExtent_26(id0,id1,id2,id3); }

  private native void ComputePointStructuredCoords_27(int id0,int id1[],int id2[],int id3);
  public void ComputePointStructuredCoords(int id0,int id1[],int id2[],int id3)
    { ComputePointStructuredCoords_27(id0,id1,id2,id3); }

  public vtkStructuredData() { super(); }

  public vtkStructuredData(long id) { super(id); }

}
